@@ -1,4 +1,4 @@
-from hub import TaskHub, HubManager
+from .hub import TaskHub, HubManager
 
 def connect(ip:str,port:int,passwd:str):
     HubManager.register('get_hub')
