@@ -1,7 +1,7 @@
 
-from hub import TaskHub,HubManager
+from .hub import TaskHub,HubManager
+from .connector import connect
 from multiprocessing import Process
-from connector import connect
 import time
 
 
